@@ -197,22 +197,32 @@ class Interconnection:
 
             logging.info(f"Using substation file: {self.substation_file}")
 
-            # load and reproject
+            # load file
             gdf = gpd.read_file(self.substation_file)
 
-            # make all column names lower case
-            gdf.columns = [i.lower() for i in gdf.columns]
+            # detect existing raster value binning for rasterization
+            if '_rval_' in gdf.columns:
 
-            # assign a field to rasterize by containing the cost of transmission per km
-            gdf['_rval_'] = 0
+                logging.info("Using current '_rval_' field found in substation file which is used in rasterization.")
+                logging.info("If '_rval_' field was included unintentionally, please remove from file and re-run.")
 
-            for i in self.transmission_costs_dict.keys():
-                gdf['_rval_'] = np.where((gdf['min_volt'] >= self.transmission_costs_dict[i]['min_voltage']) &
-                                         (gdf['min_volt'] <= self.transmission_costs_dict[i]['max_voltage']),
-                                         self.transmission_costs_dict[i]['dollar_per_km'],
-                                         gdf['_rval_'])
+                return gdf
 
-            return gdf
+            else:
+
+                # make all column names lower case
+                gdf.columns = [i.lower() for i in gdf.columns]
+
+                # assign a field to rasterize by containing the cost of transmission per km
+                gdf['_rval_'] = 0
+
+                for i in self.transmission_costs_dict.keys():
+                    gdf['_rval_'] = np.where((gdf['min_volt'] >= self.transmission_costs_dict[i]['min_voltage']) &
+                                             (gdf['min_volt'] <= self.transmission_costs_dict[i]['max_voltage']),
+                                             self.transmission_costs_dict[i]['thous_dollar_per_km'],
+                                             gdf['_rval_'])
+
+                return gdf
 
     def process_pipelines(self):
         """Select natural gas pipelines data that have a length greater than 0.
@@ -332,7 +342,7 @@ class Interconnection:
 
             with rasterio.open(out_costs, 'w', **metadata) as out:
 
-                # distance in km * the cost of the nearest substation; outputs $/km
+                # distance in km * the cost of the nearest substation; outputs thous$/km
                 cost_arr = (dist_arr * m_to_km_factor) * alloc_arr
 
                 out.write(cost_arr, 1)
@@ -357,16 +367,16 @@ class Interconnection:
             discount_rate = self.technology_dict[i].get('discount_rate')
             lifetime = self.technology_dict[i].get('lifetime')
 
-            # calulate annuity factor for technology
+            # calculate annuity factor for technology
             annuity_factor = self.calc_annuity_factor(discount_rate=discount_rate, lifetime=lifetime)
 
-            # get transmission cost array
-            substation_cost_array = self.substation_costs * annuity_factor
+            # get transmission cost array and convert from thous$/km to $/km
+            substation_cost_array = self.substation_costs * annuity_factor * 1000
 
             if require_pipelines:
 
-                # get pipeline cost array
-                pipeline_cost_array = self.pipeline_costs * annuity_factor
+                # get pipeline cost array and convert from thous$/km to $/km
+                pipeline_cost_array = self.pipeline_costs * annuity_factor * 1000
 
                 # calculate technology specific interconnection cost
                 total_interconection_cost_array = substation_cost_array + pipeline_cost_array
@@ -424,7 +434,7 @@ def preprocess_hifld_substations(substation_file, output_file=None):
     for i in transmission_costs_dict.keys():
         gdf['_rval_'] = np.where((gdf['min_volt'] >= transmission_costs_dict[i]['min_voltage']) &
                                  (gdf['min_volt'] <= transmission_costs_dict[i]['max_voltage']),
-                                 transmission_costs_dict[i]['dollar_per_km'],
+                                 transmission_costs_dict[i]['thous_dollar_per_km'],
                                  gdf['_rval_'])
 
     if output_file is not None:
